@@ -5,29 +5,15 @@ package Apache::Sling::AuthnUtil;
 use 5.008008;
 use strict;
 use warnings;
+use Carp;
 
 require Exporter;
 
-our @ISA = qw(Exporter);
+use base qw(Exporter);
 
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
+our @EXPORT_OK = ();
 
-# This allows declaration	use Apache::Sling ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-	
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
-	
-);
-
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 NAME
 
@@ -51,10 +37,11 @@ the system via a basic auth based login.
 =cut
 
 sub basic_login_setup {
-    my ( $baseURL ) = @_;
-    die "No base url defined!" unless defined $baseURL;
+    my ($baseURL) = @_;
+    croak "No base url defined!" unless defined $baseURL;
     return "get $baseURL/system/sling/login?sling:authRequestLogin=1";
 }
+
 #}}}
 
 #{{{sub basic_login_eval
@@ -68,9 +55,10 @@ Verify whether the log in attempt for the user to the system was successful.
 =cut
 
 sub basic_login_eval {
-    my ( $res ) = @_;
-    return ( $$res->code =~ /^200$/ );
+    my ($res) = @_;
+    return ( $$res->code =~ /^200$/x );
 }
+
 #}}}
 
 #{{{sub form_login_setup
@@ -86,12 +74,17 @@ the system via a form based login.
 
 sub form_login_setup {
     my ( $baseURL, $username, $password ) = @_;
-    die "No base url defined!" unless defined $baseURL;
-    die "No username supplied to attempt logging in with!" unless defined $username;
-    die "No password supplied to attempt logging in with for user name: $username!" unless defined $password;
-    my $postVariables = "\$postVariables = ['sakaiauth:un','$username','sakaiauth:pw','$password','sakaiauth:login','1']";
+    croak "No base url defined!" unless defined $baseURL;
+    croak "No username supplied to attempt logging in with!"
+      unless defined $username;
+    croak
+"No password supplied to attempt logging in with for user name: $username!"
+      unless defined $password;
+    my $postVariables =
+"\$postVariables = ['sakaiauth:un','$username','sakaiauth:pw','$password','sakaiauth:login','1']";
     return "post $baseURL/system/sling/formlogin $postVariables";
 }
+
 #}}}
 
 #{{{sub form_login_eval
@@ -105,9 +98,10 @@ Verify whether the log in attempt for the user to the system was successful.
 =cut
 
 sub form_login_eval {
-    my ( $res ) = @_;
-    return ( $$res->code =~ /^200$/ );
+    my ($res) = @_;
+    return ( $$res->code =~ /^200$/x );
 }
+
 #}}}
 
 #{{{sub form_logout_setup
@@ -122,11 +116,12 @@ the system via a form based mechanism.
 =cut
 
 sub form_logout_setup {
-    my ( $baseURL ) = @_;
-    die "No base url defined!" unless defined $baseURL;
+    my ($baseURL) = @_;
+    croak "No base url defined!" unless defined $baseURL;
     my $postVariables = "\$postVariables = ['sakaiauth:logout','1']";
     return "post $baseURL/system/sling/formlogin $postVariables";
 }
+
 #}}}
 
 #{{{sub form_logout_eval
@@ -140,9 +135,10 @@ Verify whether the log out attempt for the user from the system was successful.
 =cut
 
 sub form_logout_eval {
-    my ( $res ) = @_;
-    return ( $$res->code =~ /^200$/ );
+    my ($res) = @_;
+    return ( $$res->code =~ /^200$/x );
 }
+
 #}}}
 
 1;
